==> brian-1.0.0.zip: brian-1.0.0/brian/credits.py <==
# ----------------------------------------------------------------------------------
# Copyright ENS, INRIA, CNRS
# Contributors: Romain Brette (brette@di.ens.fr) and Dan Goodman (goodman@di.ens.fr)
# 
# Brian is a computer program whose purpose is to simulate models
# of biological neural networks.
# 
# This software is governed by the CeCILL license under French law and
# abiding by the rules of distribution of free software.  You can  use, 
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info". 
# 
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability. 
# 
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or 
# data to be ensured and,  more generally, to use and operate it in the 
# same conditions as regards security. 
# 
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.
# ----------------------------------------------------------------------------------
# 
'''
Functions that return contributor information on Brian functions,
classes and modules.
'''

__all__=['credits']

from types import StringType

from inspect import getmodule

def credits(obj=None):
    '''
    Returns a dictionnary with credits for an object.
    '''
    # TODO: if obj is a file name, find credits for file + objects used
    if obj is None:
        authors=[]
        for x in globals():
            if hasattr(x,'.__credits__') and ('author' in x.__credits__):
                if type(authors)==StringType:
                    authors.append(x.__credits__['author'])
                else: # list
                    authors+=x.__credits__['author']
        return dict(authors=list(set(authors)))
    else:
        d={}
        m=getmodule(obj) # does not seem to work!
        try:
            d.update(m.__credits__)
        except:
            pass
        try:
            d.update(obj.__credits__)
        except:
            pass
        return d

==> brian-1.1.0.zip: brian-1.1.0/brian/credits.py <==
# ----------------------------------------------------------------------------------
# Copyright ENS, INRIA, CNRS
# Contributors: Romain Brette (brette@di.ens.fr) and Dan Goodman (goodman@di.ens.fr)
# 
# Brian is a computer program whose purpose is to simulate models
# of biological neural networks.
# 
# This software is governed by the CeCILL license under French law and
# abiding by the rules of distribution of free software.  You can  use, 
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info". 
# 
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability. 
# 
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or 
# data to be ensured and,  more generally, to use and operate it in the 
# same conditions as regards security. 
# 
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.
# ----------------------------------------------------------------------------------
# 
'''
Functions that return contributor information on Brian functions,
classes and modules.
'''

__all__=['credits','author']

from types import StringType

from inspect import getmodule,getsource
import re

def credits(obj=None):
    '''
    Returns a dictionnary with credits for an object.
    '''
    # TODO: if obj is a file name, find credits for file + objects used
    if obj is None:
        authors=[]
        for x in globals():
            if hasattr(x,'.__credits__') and ('author' in x.__credits__):
                if type(authors)==StringType:
                    authors.append(x.__credits__['author'])
                else: # list
                    authors+=x.__credits__['author']
        return dict(authors=list(set(authors)))
    else:
        d={}
        m=getmodule(obj) # does not seem to work!
        try:
            d.update(m.__credits__)
        except:
            pass
        try:
            d.update(obj.__credits__)
        except:
            pass
        return d

def author(obj):
    '''
    A stupid function that returns the most likely author(s) of the object (Dan or Romain),
    guessing from code style.
    TODO: remove comments from code.
    '''
    text=getsource(obj)
    dan,romain=False,False
    authors=[]

    # Remove comments/strings
    text=re.sub(r'#.*?\n','',text)
    p=re.compile(r'""".*?"""',flags=re.S)
    text=p.sub('',text)
    p=re.compile(r"'''.*?'''",flags=re.S)
    text=p.sub('',text)

    # Guess from spaces
    if re.search(r', \b',text): dan=True
    if re.search(r'\b = \b',text): dan=True    
    if re.search(r',\b',text): romain=True
    if re.search(r'\b=\b',text): romain=True    
    
    if dan: authors+=["Dan"]
    if romain: authors+=["Romain"]
    return authors
